@@ -5,7 +5,9 @@ from tabulate import tabulate
 import websockets
 import asyncio
 
-from .app_init_command import AppInitCommand
+from .app_sdk.app_init_command import AppInitCommand
+from .app_sdk.app_build_command import AppBuildCommand
+from .app_sdk.app_install_command import AppInstallCommand
 
 
 class AppCommand(CliCommand):
@@ -19,7 +21,9 @@ class AppCommand(CliCommand):
         self._apps_api_endpoint_ws = f"ws://{config['device_address']}/api/apps/v1.0"
 
         self._subcommand_modules = {
-            'init': AppInitCommand(config)
+            'init': AppInitCommand(config),
+            'build': AppBuildCommand(config),
+            'install': AppInstallCommand(config)
         }
 
     def setup_parser(self, parser):
@@ -60,6 +64,12 @@ class AppCommand(CliCommand):
             parser = command_subparsers.add_parser(name, help=command.help())
             command.setup_parser(parser)
 
+    def needs_device(self, args):
+        command = args.app_command
+        if command in self._subcommand_modules:
+            return self._subcommand_modules[command].needs_device(args)
+        return True
+
     def run(self, args):
         command = args.app_command
         aliases = {
