@@ -117,9 +117,12 @@ class AppBuildCommand(CliCommand):
                 'services': {}
             }
             for name, service_config in meta['services'].items():
-                compose['services'][name] = {
-                    'build': service_config['build']
-                }
+                compose['services'][name] = {}
+                if 'build' in service_config:
+                    compose['services'][name]['build'] = service_config['build']
+                elif 'image' in service_config:
+                    compose['services'][name]['image'] = service_config['image']
+
             # api version 1 still allows for dict update
             if 'compose-override' in meta:
                 deep_dict_update(compose, meta['compose-override'])
