@@ -15,10 +15,16 @@ def ensure_docker():
     result = subprocess.run(['docker', 'version', '--format', '{{json .}}'],
                             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     if result.returncode != 0:
-        exit('Docker not found on this system. Make sure that docker is installed, running and reachable.')
+        error('Docker not found on this system. Make sure that docker is installed, running and reachable.')
     res = json.loads(result.stdout.decode())
     print(f'.. Found docker client {res["Client"]["Version"]}, server {res["Server"]["Version"]}')
 
+    result = subprocess.run(['docker', 'compose', 'version'])
+    if result.returncode != 0:
+        error('Docker compose plugin not found on this system. Make sure you have docker compose installed. \n'
+              'E.g. on ubuntu, you can install it with \'sudo apt-get install docker-compose-plugin\'')
+    print('.. Found docker compose plugin')
+
 
 def _test_mender_artifact(artifact_path):
     result = subprocess.run([artifact_path, '--version'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
